capture log close
clear mata
clear
# delimit ;
set memory 50m ;
set more off ;
pause on ;

* =============================================================== ;
*	This is makepollsallvars.do ; 
*	Last edited 12/30/08 ew ;
*	Uses presprepolls.dta pres_results.dta exitmeans.dta;
*	Merges data, creates analysis vars;
*	Creates poll level dataset pollsallvars.dta of polls, results, and exits;
*	Creates state level dataset statevars.dta of results and exits;
* =============================================================== ;

global N=1;
*1==umich server structure;

if $N==1 {;
global prog "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/";
global res "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/";
global pre "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/";
global exit "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/exitpolls/";
};


log using "${prog}makepollsallvars.log", replace ;
display "$S_DATE" ;


use ${res}pres_results.dta;
mmerge state using ${exit}exitmeans.dta, t(1:1);
drop _m;
sum; des;
save ${prog}statevars.dta, replace;

*state-year dataset to ensure we have obs for all states and years;
use ${prog}statevars.dta;
keep state;
expand 3;
egen tags=tag(state);
gen year=2000 if tags==1;
drop tags;
egen tags=tag(state) if year==.;
replace year=2004 if tags==1;
drop tags;
replace year=2008 if year==.;
tab year;

mmerge state year using ${pre}presprepolls.dta, t(1:n);
mmerge state using ${prog}statevars.dta, t(n:1);
drop _m;
sum; des;

* =============== ;
* Label variables ;
* =============== ;

for num 1996 2000 2004 2008:
 label variable repfinX "Republican actual percentage of vote, X" \
 label variable demfinX "Democrat actual percentage of vote, X" \
 label variable allothfinX "All non R/D votes actual percentage of vote, X" ;

* ============================== ;
* Contemporaneous results/exits ;
* ============================== ;

for any dem rep alloth: gen Xfin=. \ gen Xexit=. \ 
	gen seX0exit=. \ gen seX1exit=. \ gen seX2exit=.;

for num 2000 2004 2008:
 replace demfin=demfinX if year==X \
 replace repfin=repfinX if year==X \
 replace allothfin=allothfinX if year==X ;
for num 2000 2004:
 replace demexit=demexitX if year==X \
 replace repexit=repexitX if year==X \
 replace allothexit=allothexitX if year==X \
 replace sedem0exit=sedem0exitX if year==X \
 replace serep0exit=serep0exitX if year==X \
 replace sealloth0exit=sealloth0exitX if year==X \
 replace sedem1exit=sedem1exitX if year==X \
 replace serep1exit=serep1exitX if year==X \
 replace sealloth1exit=sealloth1exitX if year==X \
 replace sedem2exit=sedem2exitX if year==X \
 replace serep2exit=serep2exitX if year==X \
 replace sealloth2exit=sealloth2exitX if year==X ;
sum dem* rep* alloth* ;

* ------------------------------------ ;
* Sum of actual/exit probabilities, _totfin ;
*	Note: _totfin = totact ;
* ------------------------------------ ;

egen _totfin = rsum(demfin repfin allothfin);
label variable _totfin "Total actual percentages" ;
egen tagr=tag(raceid);
sum _totfin if tagr==1, d ;
egen _totexit = rsum(demexit repexit allothexit);
label variable _totexit "Total exit poll percentages" ;
sum _totexit if tagr==1&(year==2000|year==2004), d ;
drop tagr _totfin _totexit;
*totact and totexit are 100 for all races;

* -------------------------------------------- ;
* Create normalized prediction error variables ;
*   Predicted - actual ;
* -------------------------------------------- ;

egen demmean = mean(dem1), by(raceid) ;
egen repmean = mean(rep1), by(raceid) ;
/*
egen indmean = mean(ind1), by(raceid) ;
egen greenmean = mean(green1), by(raceid) ;
egen refmean = mean(ref1), by(raceid) ;
egen libmean = mean(lib1), by(raceid) ;
*/

/*
gen demcon = demmean*(racen/(racen-1)) - dem1/(racen-1) if racen > 2 ;
gen repcon = repmean*(racen/(racen-1)) - rep1/(racen-1) if racen > 2 ;
gen indcon = indmean*(racen/(racen-1)) - ind1/(racen-1) if racen > 2 ;
gen greencon = greenmean*(racen/(racen-1)) - green1/(racen-1) if racen > 2 ;
gen refcon = refmean*(racen/(racen-1)) - ref1/(racen-1) if racen > 2 ;
label variable demcon "Mean Dem 1 prediction in race, less this poll" ;
label variable repcon "Mean Rep 1 prediction in race, less this poll" ;
*/

gen turnoutpr = totpred - 100 ;
gen dempe_fin = dem1 - demfin ;
gen reppe_fin = rep1 - repfin ;
gen demstd_fin = sqrt(samplesize)*
	(dem1/100 - demfin/100)/sqrt((demfin/100)*(1-(demfin/100))) ;
gen repstd_fin = sqrt(samplesize)*
	(rep1/100 - repfin/100)/sqrt((repfin/100)*(1-(repfin/100))) ;

/*
gen indstd = sqrt(samplesize)*
	(ind1/100 - ind1fin/100)/sqrt((ind1fin/100)*(1-(ind1fin/100))) ;
gen greenstd = sqrt(samplesize)*
	(green1/100 - green1fin/100)/sqrt((green1fin/100)*(1-(green1fin/100))) ;
gen refstd = sqrt(samplesize)*
	(ref1/100 - ref1fin/100)/sqrt((ref1fin/100)*(1-(ref1fin/100))) ;
*/

gen dempe_ep = dem1 - demexit ;
gen reppe_ep = rep1 - repexit ;
gen demstd_ep = sqrt(samplesize)*
	(dem1/100 - demexit/100)/sqrt((demexit/100)*(1-(demexit/100))) ;
gen repstd_ep = sqrt(samplesize)*
	(rep1/100 - repexit/100)/sqrt((repexit/100)*(1-(repexit/100))) ;

label variable turnoutpr "Turnout prediction error (totpred - totact)" ;
label variable demstd_fin "Standardized Dem 1 prediction error" ;
label variable repstd_fin "Standardized Rep 1 prediction error" ;
label variable dempe_fin "Dem 1 prediction error" ;
label variable reppe_fin "Rep 1 prediction error" ;
label variable demstd_ep "Standardized Dem 1 prediction error, using exit polls" ;
label variable repstd_ep "Standardized Rep 1 prediction error, using exit polls" ;
label variable dempe_ep "Dem 1 prediction error, using exit polls" ;
label variable reppe_ep "Rep 1 prediction error, using exit polls" ;


* -------------------------------------------- ;
* standardized exit poll errors;
* -------------------------------------------- ;

gen epdempe = demexit - demfin;
gen epreppe = repexit - repfin;
gen ep_n=nobsexit2000 if year==2000;
replace ep_n=nobsexit2004 if year==2004;

***these don't account for weights in exit poll data***;
gen n1sedemexit=sqrt((demexit/100)*(1-(demexit/100)))/sqrt(ep_n);
gen n1serepexit=sqrt((repexit/100)*(1-(repexit/100)))/sqrt(ep_n);
gen n2sedemexit=sqrt((demfin/100)*(1-(demfin/100)))/sqrt(ep_n);
gen n2serepexit=sqrt((repfin/100)*(1-(repfin/100)))/sqrt(ep_n);
gen epdemstd_now = sqrt(ep_n)*
	(demexit/100 - demfin/100)/sqrt((demfin/100)*(1-(demfin/100))) ;
gen eprepstd_now = sqrt(ep_n)*
	(repexit/100 - repfin/100)/sqrt((repfin/100)*(1-(repfin/100))) ;


*use estimated standard errors from deaton and svy;
egen tmp=tag(state year);
bysort year: sum n1sedemexit n2sedemexit sedem0exit sedem1exit sedem2exit
	         n1serepexit n2serepexit serep0exit serep1exit serep2exit if tmp==1;
gen epdemstd1 = (demexit/100 - demfin/100)/sedem1exit;
gen eprepstd1 = (repexit/100 - repfin/100)/serep1exit;
gen epdemstd2 = (demexit/100 - demfin/100)/sedem2exit;
gen eprepstd2 = (repexit/100 - repfin/100)/serep2exit;
bysort year: sum epdemstd* eprepstd* if tmp==1;
sum epdemstd* eprepstd* if tmp==1;
drop tmp;

label variable ep_n "Exit poll sample size";
label variable epdemstd2 "Standardized Dem exit poll prediction error" ;
label variable eprepstd2 "Standardized Rep exit poll prediction error" ;
label variable epdempe "Dem exit poll prediction error" ;
label variable epreppe "Rep exit poll prediction error" ;



* -------------------------------------------- ;
* Create `ahead' variables ;
* -------------------------------------------- ;

gen demahead = (dem1 - rep1 > 0) ;
gen repahead = (rep1 - dem1 > 0) ;
gen demahead_fin = (demfin - repfin > 0) ;
gen repahead_fin = (repfin - demfin > 0) ;
gen demahead_ep = (demexit - repexit > 0) ;
gen repahead_ep = (repexit - demexit > 0) ;

label variable demahead "Dem 1 pred. ahead of Rep 1" ;
label variable repahead "Rep 1 pred. ahead of Dem 1" ;
label variable demahead_fin "Dem 1 act. ahead of Rep 1" ;
label variable repahead_fin "Rep 1 act. ahead of Dem 1" ;
label variable demahead_ep "Dem 1 ahead of Rep 1 in exit polls" ;
label variable repahead_ep "Rep 1 ahead of Dem 1 in exit polls" ;

* ------------------ ;
* Assorted variables ;
* ------------------ ;

gen lt2wks = (daysbef <= 14) if daysbef ~= . ;
gen gt2wks = (daysbef > 14) if daysbef ~= . ;

gen demacwon=demfin>repfin&demfin!=.;
gen repacwon=repfin>demfin&repfin!=.;
egen tagr=tag(raceid);
bysort year: tab demacwon if tagr==1,m; 
bysort year: tab repacwon if tagr==1,m;
* correct presidential "ties" - these were an issue when we were rounding off results;
replace demacwon=1 if state=="Oregon" & year==2000;
replace repacwon=0 if state=="Oregon" & year==2000;
replace demacwon=1 if state=="Wisconsin" & year==2000;
replace repacwon=0 if state=="Wisconsin" & year==2000;
replace demacwon=1 if state=="New Mexico" & year==2000;
replace repacwon=0 if state=="New Mexico" & year==2000;
replace repacwon=1 if state=="Florida" & year==2000;
replace demacwon=0 if state=="Florida" & year==2000;
bysort year: tab demacwon if tagr==1,m;
bysort year: tab repacwon if tagr==1,m;
drop tagr;

gen incorrect=(repahead & ~repacwon) | (demahead & ~demacwon);
gen corr=(repahead & repacwon) | (demahead & demacwon);
*note: for house and senate races there are cases of independents winning, so the code
	above would need to be changed. not an issue for pres;
*count tied polls as incorrect;
gen predicttie=repahead==0&demahead==0;
sum demfin repfin if predicttie==1, det;
replace incorrect=1 if predicttie==1;
replace corr=0 if predicttie==1;
tab incorrect corr, m;

label variable lt2wks "Poll taken less than 2 weeks before election" ;
label variable gt2wks "Poll taken 2 weeks or more before election" ;
label variable repacwon "Republican 1 won" ;
label variable demacwon "Democrat 1 won" ;
label variable incorrect "Predicted victor incorrect (includes tied polls)" ;
label variable corr "Predicted victor incorrect (tied polls fail)" ;
label variable predicttie "Predicted tie";

* -------------------------------------------- ;
* Treat undecideds as strongly ignorable;
* -------------------------------------------- ;

egen tmp_nound=rsum(rep1 dem1 alloth) ;
gen rep1new = (rep1 * 100) / (tmp_nound) ;
gen dem1new = (dem1 * 100) / (tmp_nound) ;
gen newn_put50 = (100 - allundec) * putn_50 / 100 ;
gen newn = (100 - allundec) * samplesize / 100 ;
drop tmp_nound ;

label variable rep1new "Predicted Rep, ignoring undecideds" ;
label variable dem1new "Predicted Dem, ignoring undecideds" ;
label variable newn "Reported sample size, ignoring undecideds" ;

* -------------------------------------------- ;
* Create normalized prediction error variables ;
*   Predicted - actual ;
* -------------------------------------------- ;

gen dempe2_fin = dem1new - demfin ;
gen reppe2_fin = rep1new - repfin ;
gen demstd2_fin = sqrt(samplesize)*
	(dem1new/100 - demfin/100)/sqrt((demfin/100)*(1-(demfin/100))) ;
gen repstd2_fin = sqrt(samplesize)*
	(rep1new/100 - repfin/100)/sqrt((repfin/100)*(1-(repfin/100))) ;

gen dempe2_ep = dem1new - demexit ;
gen reppe2_ep = rep1new - repexit ;
gen demstd2_ep = sqrt(samplesize)*
	(dem1new/100 - demexit/100)/sqrt((demexit/100)*(1-(demexit/100))) ;
gen repstd2_ep = sqrt(samplesize)*
	(rep1new/100 - repexit/100)/sqrt((repexit/100)*(1-(repexit/100))) ;

label variable demstd2_fin "Standardized Dem 1 prediction error, ignoring undecided" ;
label variable repstd2_fin "Standardized Rep 1 prediction error, ignoring undecided" ;
label variable demstd2_ep
 "Standardized Dem 1 prediction error using exit polls, ignoring undecided" ;
label variable repstd2_ep
 "Standardized Rep 1 prediction error using exit polls, ignoring undecided" ;

sum rep1 dem1 samplesize rep1new dem1new newn
	demstd_fin repstd_fin demstd2_fin repstd2_fin;
sum rep1 dem1 samplesize rep1new dem1new newn
	demstd_ep repstd_ep demstd2_ep repstd2_ep if year==2000|year==2004;


***some other variables for tables***;
gen likely=vtype=="l";
gen indother=alloth>0&alloth!=.;
for num 1996 2000 2004 2008: gen repacwon_X=repfinX>demfinX if repfinX!=.;
for num 1996 2000 2004 2008: gen demacwon_X=demfinX>repfinX if demfinX!=.;
gen incorrect_pre=(repacwon_1996==1&demacwon_2000==1)|
                  (demacwon_1996==1&repacwon_2000==1) if year==2000;
replace incorrect_pre=(repacwon_2000==1&demacwon_2004==1)|
                  (demacwon_2000==1&repacwon_2004==1) if year==2004;
replace incorrect_pre=(repacwon_2004==1&demacwon_2008==1)|
                  (demacwon_2004==1&repacwon_2008==1) if year==2008;
gen nader=(green1!=.&green1!=0&year==2000)|(ind1!=.&ind1!=0&year!=2000);
gen buch=ref1!=.&ref1!=0 if year==2000;

gen daysbef2=daysbef^2 ;
gen absdemstd2_fin=abs(demstd2_fin) ;
gen absrepstd2_fin=abs(repstd2_fin) ;
gen absdempe2_fin=abs(dempe2_fin) ;
gen absreppe2_fin=abs(reppe2_fin) ;
label var dempe2_fin "Dem. prediction error" ;
label var reppe2_fin "Rep. prediction error" ;
label var absdempe2_fin "Abs. val. Dem. prediction error" ;
label var absreppe2_fin "Abs. val. Rep. prediction error" ;

for any dem rep:
 gen Xprior=Xfin2004 if year==2008 \
 replace Xprior=Xfin2000 if year==2004 \
 replace Xprior=Xfin1996 if year==2000 ;

gen fracund=allundec/100 ;
replace fracund=. if indundec==0;
gen fracoth=alloth/100;
replace fracoth=. if indother==0;


/*
*skip this section for now;
* =================================================== ;
* B1. Treat reported undecideds, totpred < 100 as rep ;
* =================================================== ;

egen tmp_all=rsum(rep1 dem1 tototh allundec) ;
gen rep1rep = ((rep1 + allundec)*100) / (tmp_all) ;
gen dem1rep = (dem1 *100) / (tmp_all) ;
label variable rep1rep "Predicted Rep, undecideds = Rep" ;
label variable dem1rep "Predicted Dem, undecideds = Rep" ;

egen repmeanr = mean(rep1rep), by(raceid) ;
gen repstdr = sqrt(samplesize)*(rep1rep/100 - rep1fin/100)/sqrt((rep1fin/100)*(1-(rep1fin/100))) ;
label variable repmeanr "Mean of rep1rep by race" ;
label variable repstdr "Standardized Rep 1 prediction error, undecided = Republican" ;
 
egen demmeanr = mean(dem1rep), by(raceid) ;
gen demstdr = sqrt(samplesize)*(dem1rep/100 - dem1fin/100)/sqrt((dem1fin/100)*(1-(dem1fin/100))) ;
label variable demmeanr "Mean of dem1rep by race" ;
label variable demstdr "Standardized Dem 1 prediction error, undecided = Republican" ;

* =================================================== ;
* B2. Treat reported undecideds, totpred < 100 as dem ;
* =================================================== ;

gen dem1dem = ((dem1 + allundec)*100) / (tmp_all) ;
gen rep1dem = (rep1 *100) / (tmp_all) ;
drop tmp_all ;

label variable dem1dem "Predicted Dem, undecideds = Dem" ;
label variable rep1dem "Predicted Rep, undecideds = Dem" ;

egen demmeand = mean(dem1dem), by(raceid) ;
gen demstdd = sqrt(samplesize)*(dem1dem/100 - dem1fin/100)/sqrt((dem1fin/100)*(1-(dem1fin/100))) ;
label variable demmeand "Mean of dem1dem by race" ;
label variable demstdd "Standardized Dem 1 prediction error, undecided = Democrat" ;

egen repmeand = mean(rep1dem), by(raceid) ;
gen repstdd = sqrt(samplesize)*(rep1dem/100 - rep1fin/100)/sqrt((rep1fin/100)*(1-(rep1fin/100))) ;
label variable repmeand "Mean of rep1dem by race" ;
label variable repstdd "Standardized Rep 1 prediction error, undecided = Democrat" ;

sum rep1rep rep1dem repstdr repstdd dem1rep dem1dem demstdr demstdd ;

* =================================== ;
* C. Fraction of indecisive elections ;
* =================================== ;

* Republican ;

gen repprwinr = (rep1rep > rpnxtmax & rep1rep ~= .) ;
gen repprwind = (rep1dem > rpnxtmax & rep1dem ~= .) ;

egen diffrep = diff(repprwind repprwinr) ; *repprwin ;

label variable repprwinr "Reps predicted to win, undecided = Rep" ;
label variable repprwind "Reps predicted to win, undecided = Dem" ;
label variable diffrep "Difference in reps predicted to win, undec = rep or dem?" ;

*gen repprg50 = (rep1 > 50 & rep1 ~= .) ;
gen repprg50r = (rep1rep > 50 & rep1rep ~= .) ;
gen repprg50d = (rep1dem > 50 & rep1dem ~= .) ;
egen diffrep50 = diff(repprg50d repprg50r) ;

label variable repprg50r "Reps predicted >50, undecided = Rep" ;
label variable repprg50d "Reps predicted >50, undecided = Dem" ;
label variable diffrep50 "Difference in reps predicted >50, undec = rep or dem?" ;

sum repprwind repprwinr diffrep repprg50d repprg50r diffrep50 ;

* Democrat ;

gen demprwind = (dem1dem > dpnxtmax & dem1dem ~= .) ;
gen demprwinr = (dem1rep > dpnxtmax & dem1rep ~= .) ;

egen diffdem = diff(demprwinr demprwind) ;

label variable demprwinr "Dems predicted to win, undecided = Rep" ;
label variable demprwind "Dems predicted to win, undecided = Dem" ;
label variable diffdem "Difference in dems predicted to win, undec = rep or dem?" ;

*gen demprg50 = (dem1 > 50 & dem1 ~= .) ;
gen demprg50d = (dem1dem > 50 & dem1dem ~= .) ;
gen demprg50r = (dem1rep > 50 & dem1rep ~= .) ;
egen diffdem50 = diff(demprg50d demprg50r) ;

label variable demprg50r "Dems predicted >50, undecided = Rep" ;
label variable demprg50d "Dems predicted >50, undecided = Dem" ;
label variable diffdem50 "Difference in dems predicted >50, undec = rep or dem?" ;

sum demprwind demprwinr diffdem demprg50d demprg50r diffdem50 ;
*/



***drop 44 polls with missing sample size***;
**7 in 2000, 36 in 2004, 1 in 2008**;
*want to be sure to keep at least one obs per state year (for exit polls, etc.);
egen tmp=count(record), by(state year);
tab tmp if samplesize==.;
tab state if tmp==1&samplesize==.;
for var rep1 dem1 totpred predless enddate startdate polldur daysbef dem1_dr
	other undecided otherundecided none totothers racen allundec alloth
	indundec lt2wks gt2wks demahead* repahead* incorrect corr predic rep1new dem1new
	dempe* reppe* demstd* repstd* likely indother nader daysbef2 abs* fracund fracoth
	record: replace X=. if tmp==1&samplesize==.;
for var vtype: replace X="" if tmp==1&samplesize==.;
tab year if samplesize==.&tmp>1;
drop if samplesize==.&tmp>1;


*main analysis sample - for polls that report multiple samples or questions
                        exclude the one that limits options to only 2 parties
                        exclude the one that reports a "less likely" voter sample;
gen mainsamp=duprep_3p!=0&duprep_lv!=0;

*robustness check sample - include the limitied to 2 party poll instead;
gen robustsamp=duprep_3p!=1&duprep_lv!=0;

egen tagr=tag(raceid) if mainsamp==1;


gen party=sourceparty!="n"|sponsorparty!="n";
label var party "any party affiliation for poll";

***major source or sponsor indicators***;
forval s=1/6 {;
 egen tagsource`s'=tag(source`s');
 egen tmp`s'=count(raceid), by(source`s');
 sort tmp`s';
 list source`s' tmp`s' if tagsource`s'==1;
};
*majorsource includes any source with at least 40 polls in the sample;
gen majorsource=(tmp1>=40&source1!="."&source1!="")
		|(tmp2>=40&source2!="."&source2!="")
		|(tmp3>=40&source3!="."&source3!="");
*clean up to also include alternate coding/spelling of source;
*include morning call, zogby, mason-dixon, ARG, reuters, ORC, CNN, Quinnipiac U.,
	research 2000, strategic vision, Muhlenberg College, USA today, gallup;
replace majorsource=1 if source1=="Quinn"|source1=="Mason-Dixon poll"
	|source1=="Zogby International"|source1=="Mason-Dixon"|source1=="Reuters"
	|source1=="R2000"|source1=="QU"||source2=="Gallup";
drop tags* tmp*;
tab majorsource;

*now also look at sponsor;
forval s=1/4 {;
 egen tagsponsor`s'=tag(sponsor`s');
 egen tmp`s'=count(raceid), by(sponsor`s');
 sort tmp`s';
 list sponsor`s' tmp`s' if tagsponsor`s'==1;
};
*again use >40;
replace majorsource=1 if sponsor1=="Daily Kos."|sponsor1=="CNN"|sponsor2=="Time";
*also include MSNBC and other clean-up;
replace majorsource=1 if sponsor1=="Reuters/MSNBC"|sponsor1=="Ruters/MSNBC"|
	sponsor2=="MSNBC";
drop tags* tmp*;
tab majorsource;



compress ;
label data "Polling data (pollsallvars.dta), all variables created" ;
save "${prog}pollsallvars.dta", replace ;

log close ;
