capture log close
clear
clear mata
# delimit ;
set memory 50m ;
set more off ;
pause on ;
program drop _all ;
estimates clear ;

* =============================================================== ;
*	This is fig1.do ; 
*	Last edited 12/30/08 ew ;
*	Uses pollsallvars.dta ;
*	FIG 1: Prediciton error density by election year;
*	FIG 2: Pre-election poll standardized prediction error density by poll subgroup;
*	FIG 8: Detailed subgroups;
* =============================================================== ;

global N=1;
*1==umich server structure;
*2==elias's macbook structure;

if $N==1 {;
global prog "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/";
global res "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/electres/";
global pre "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/";
global exit "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/exitpolls/";
global tab "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/tables/";
global fig "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/figures/";
global oth "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/notinpaper/";
global mktab "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/mktabsandfigs/";
};

log using "${mktab}fig1.log", replace ;
display "$S_DATE";
use "${prog}pollsallvars.dta", clear ;


program define pollden;
use "${prog}pollsallvars.dta", clear ;
keep if `1'&record!=.;

_genx z, min(-6) max(6) nbins(200) ;
gen stdnorm = normalden(z) ;
label variable stdnorm "Standard normal density" ;

* --------------------------- ;
* 1a. std pred error, all ;
* --------------------------- ;

kdensity `2'std2_`5', at(z) bw(.2) gen(pollden) nograph ;
label variable pollden "Dem. prediction error density";

/* twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density") ;
graph export "${fig}`4'peall_`5'.eps", as(eps) logo(off) replace ;*/

rename pollden pollden_all ;
qui sum `2'std2_`5'; local n=r(N);
label var pollden_all "All polls, n=`n'" ;

* ---------------------------------------------- ;
* 1b. std pred error, no <100		 ;
* ---------------------------------------------- ;

kdensity `2'std2_`5' if predless>0&predless!=., at(z) bw(.2) gen(pollden) ;
label variable pollden "Dem. prediction error density" ;

/*twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density, no <100") ;
graph export "${fig}`4'penoa_`5'.eps", as(eps) replace ;*/

rename pollden pollden_noa ;
qui sum `2'std2_`5' if predless>0&predless!=.; local n=r(N);
label var pollden_noa "Sum to 100-102, n=`n'" ;

* -------------------------------------------------- ;
* 1c. std pred error, no `other parties' problem ;
* -------------------------------------------------- ;

kdensity `2'std2_`5' if indoth==0, at(z) bw(.3) gen(pollden) ;
label variable pollden "Dem. prediction error density" ;

/*twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density, no other parties") ;
graph export "${fig}`4'peno_`5'.eps", as(eps) replace ;*/

rename pollden pollden_no ;
qui sum `2'std2_`5' if indoth==0; local n=r(N);
label var pollden_no "No third parties, n=`n'";

* ------------------------------------ ;
* 1d. std pred error, recent polls ;
* ------------------------------------ ;

kdensity `2'std2_`5' if lt2wks==1, at(z) bw(.2) gen(pollden) ;
label variable pollden "Dem. prediction error density" ;

/*twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density, polls < 2 weeks ahead") ;
graph export "${fig}`4'pelt2_`5'.eps", as(eps) replace ;*/

rename pollden pollden_lt2 ;
qui sum `2'std2_`5' if lt2wks==1; local n=r(N);
label var pollden_lt2 "< 2 weeks ahead, n=`n'" ;

* ------------------------------------------ ;
* 1e. std pred error, likely voter polls ;
* ------------------------------------------ ;

kdensity `2'std2_`5' if likely==1, at(z) bw(.2) gen(pollden) ;
label variable pollden "Dem. prediction error density" ;

/*twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density, polls of likely voters") ;
graph export "${fig}`4'pelv_`5'.eps", as(eps) replace ;*/

rename pollden pollden_lv ;
qui sum `2'std2_`5' if likely==1; local n=r(N);
label var pollden_lv "Likely voters, n=`n'" ;


* summary graph, Fig. A2 ;
twoway (line pollden_all z, clpat(longdash) clcolor(black))
	(line pollden_lv z, clpat(shortdash) clcolor(black))
	(line pollden_lt2 z, clpat(dash_dot) clcolor(black))
	(line pollden_noa z, clpat(longdash_dot) clcolor(black))
	(line pollden_no z, clpat(shortdash_dot) clcolor(black))
	(line stdnorm z, clcolor(black))
	/*,title("`3' prediction error densities")*/;
graph export "${fig}`4'pesum_`5'_all.eps", as(eps) logo(off) replace ;
* summary graph, Fig. 2, Fig. A1 (exit polls) ;
twoway (line pollden_all z, clpat(longdash) clcolor(black))
	(line pollden_lv z, clpat(shortdash) clcolor(black))
	(line pollden_lt2 z, clpat(dash_dot) clcolor(black))
	(line stdnorm z, clcolor(black))
	/*,title("`3' prediction error densities")*/;
graph export "${fig}`4'pesum_`5'.eps", as(eps) logo(off) replace ;

drop pollden* ;

* ------------------------------------------ ;
* 2. std pred error, by year		     ;
* ------------------------------------------ ;

forval y=2000(4)2008 {;
 qui sum `2'std2_`5' if year==`y';
 local mn_`y'=r(mean);
 kdensity `2'std2_`5' if year==`y', at(z) bw(.2) gen(pollden) ;
 label variable pollden "Dem. prediction error density" ;

/* twoway (line pollden z, clpat(dash) clcolor(black))
	(line stdnorm z, clcolor(black)),
	title("`3' prediction error density, `y'") ;
 graph export "${fig}`4'pe`y'_`5'.eps", as(eps) replace ;*/

 rename pollden pollden_`y' ;
 label var pollden_`y' "Polls, year `y'" ;
};

* by year summary graph, Fig 1 ;
if "`5'"=="fin" {;
 twoway (line pollden_2000 z, clpat(longdash) clcolor(black)
		 xline(`mn_2000', lpat(longdash) lcolor(black)))
	(line pollden_2004 z, clpat(shortdash) clcolor(black)
		 xline(`mn_2004', lpat(shortdash) lcolor(black)))
	(line pollden_2008 z, clpat(dash_dot) clcolor(black)
		 xline(`mn_2008', lpat(dash_dot) lcolor(black)))
	(line stdnorm z, clcolor(black) xline(0, lcolor(black)))
	/*,title("`3' prediction error densities")*/;
 graph export "${fig}`4'pesumyr_`5'.eps", as(eps) logo(off) replace ;
};
* by year summary graph, Fig A1 ;
if "`5'"=="ep" {;
 twoway (line pollden_2000 z, clpat(longdash) clcolor(black)
                 xline(`mn_2000', lpat(longdash) lcolor(black)))
        (line pollden_2004 z, clpat(shortdash) clcolor(black)
                 xline(`mn_2004', lpat(shortdash) lcolor(black)))
        (line stdnorm z, clcolor(black) xline(0, lcolor(black)))
        /*,title("`3' prediction error densities")*/;
 graph export "${fig}`4'pesumyr_`5'.eps", as(eps) logo(off) replace ;
};
drop pollden* ;

end;

pollden mainsamp==1 dem Democrat d fin;
pollden mainsamp==1 rep Republican r fin;

log close;








