capture log close
capture clear all
# delimit ;
set memory 50m ;
set more off ;
pause on ;
program drop _all ;

* =============================================================== ;
*	This is tab10.do ; 
*	Last edited 12.30.08 ew ;
*	Uses tessallvars.dta;
*	Manksi presidential poll results;
* =============================================================== ;

global N=1;
*1==umich server structure;
*2==elias's macbook structure;

if $N==1 {;
global tess "/afs/umich.edu/user/f/g/fgelias/Shared/pollproject/tess/";
global tessdata
    "/afs/umich.edu/user/f/g/fgelias/Shared/pollproject/tess/tess28_dinardo_final_data/";
global tab "/afs/umich.edu/user/f/g/fgelias/Shared/pollproject/tables/";
global mktab "/afs/umich.edu/user/f/g/fgelias/Shared/pollproject/mktabsandfigs/";
};


log using ${mktab}tab10.log, replace ;
display "$S_DATE";
use "${tess}tessallvars.dta", clear ;



*******results with wave weights ;
* results by wave ;

program define wavewgt ;
preserve ;
keep if `1' ; 

*normalize weights to sum to 1 (not necessary with aweights);
for var wwgtm wweightm wmissweightm wwgtc wweightc wmissweightc:
 sum X \
 replace X=X/r(sum);
*units of percentage points;
for var bush kerry other bushc kerryc otherc: replace X=X*100;

di "manski";
for any bush kerry other: reg X [aw=wwgtm], r \ estimates store X_1;
for any bush kerry other: reg X [aw=wwgtm] if wweightm!=0, r \ estimates store X_2;
for any bush kerry other: reg X [aw=wweightm], r \ estimates store X_3;
for any bush kerry other: reg X [aw=wmissweightm], r \ estimates store X_4;

di "control" ;
for any bushc kerryc otherc: reg X [aw=wwgtc], r \ estimates store X_1;
for any bushc kerryc otherc: reg X [aw=wwgtc] if wweightc!=0, r \ estimates store X_2;
for any bushc kerryc otherc: reg X [aw=wmissweightc], r \ estimates store X_4;

estout *1 *2 *3 *4 using ${tab}tab10_tessw`2'.txt, replace
	 cells(b(fmt(3)) se(par fmt(3))) stats(N, fmt(0));

restore ;
end ;

wavewgt wave==1 1;
wavewgt wave==2 2;
wavewgt wave!=. 12;

!cat ${tab}tab10_tessw1.txt ${tab}tab10_tessw2.txt ${tab}tab12_tessw10.txt
	> ${tab}tab10_tess.txt;


******complicated tests of joint significance;
program define jointsig;
preserve;
keep if `1';

*create numerical subscripts for each variable in the randcheck;
global i=0;
foreach v of varlist ${`2'}
  {;
     global i = 1+$i;
     capture drop var$i;
     rename `v' var$i;
  };
keep var* manski wave caseid testwgt;

*expand the data so that we have one obs per individual-outcome;
 expand $i;
 bysort caseid: gen nobs=_n;
 tab nobs, m;

*now create dummy variables for each outcome;
forvalues y = 1/$i
    {;
        gen byte d_var`y'=nobs==`y';
    };

*now interact the dummies with the main treatment variable;
forvalues y = 1/$i
    {;
	gen o_var`y'=d_var`y'*manski;
    };

*now rename the LHS variables to a common name;
gen yvar=.;
forvalues y = 1/$i
        {;
             replace yvar=var`y' if nobs==`y';
        };

*run regression;
disp "** SAMPLE = `1' **";
reg yvar d_* o_* [aw=testwgt], nocons cl(caseid);
testparm o_*;
restore;
end;


for var bush kerry other:
 replace X=Xc if manski==0 \
 replace X=X*100 \
 global X "X";

global bk "bush kerry";

gen testwgt=wmissweightc if manski==0;
replace testwgt=wmissweightm if manski==1;
sum testwgt;
replace testwgt=testwgt/r(sum);

/*
foreach var in bush kerry bk {;
 jointsig wave==1 `var';
 jointsig wave==2 `var';
 jointsig wave!=. `var';
};
*/


***simple tests of joint significance***;
foreach var in bush kerry bk {;
 reg manski ${`var'} [aw=testwgt] if wave==1, r;
 reg manski ${`var'} [aw=testwgt] if wave==2, r;
 reg manski ${`var'} [aw=testwgt] if wave!=., r;
};


log close ;
