capture log close
clear
# delimit ;
set memory 50m ;
set more off ;
pause on ;

* =============================================================== ;
*	This is makeprepoll.do ; 
*	Last edited 12/30/08 ew ;
*	Uses polls00.csv polls04.csv and polls08.csv
*	Cleans data, creates dataset presprepolls.dta ;
*	Stata v. 10;
* =============================================================== ;

global N=1;
*1==umich server structure;
*2==elias's mac structure;

if $N==1 {;
global prog "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/";
global prepoll "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/";
global prepoll00 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/2000/";
global oldpoll00
    "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/2000/old2000polls/";
global prepoll04 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/2004/";
global oldpoll04
    "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/2004/old2004polls/";
global prepoll08 "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/prepolls/2008/";
};

if $N==2 {;
global prog "/Users/fgelias/Documents/umich/projects/pollproject/final_polls/" ;
global results
 "/Users/fgelias/Documents/umich/projects/pollproject/final_polls/results/" ;
global prepoll 
"/Users/fgelias/Documents/umich/projects/pollproject/final_polls/predata/" ;
};


log using "${prog}makeprepoll.log", replace ;
display "$S_DATE" ;

* ========================= ;
* insheet pre-election poll data;
* ========================= ;

/*
*2000 and 2004 raw pre-election poll data from nationaljournal.com;
*this 2004 data is now obsolete with the new 2003 data from pollingreport.com;
foreach y in 00 04 {;
insheet using "${oldpoll`y'}20`y'pres.csv";
*don't need/want totals or election results from these files;
drop *fin totpred totact predbig predsmall badpred actbig actsmall badact;
*we don't use these;
drop type district site;
compress;
des;
save "${oldpoll`y'}20`y'pres.dta", replace;
clear;
};
*/

*2000 2004 & 2008 raw pre-election poll data from pollingreport.com;
foreach y in 00 04 08 {;
insheet using "${prepoll`y'}polls`y'.csv";
compress;
des;
*sample size issues;
tab samplesize,m;
if "`y'"=="08" {; *2004 N is numeric, 2008 is string ;
 destring samplesize, gen(samplesize2) force;
 tab samplesize if samplesize2==.;
 for num 600/638: replace samplesize2=550 if samplesize=="500-X";
 replace samplesize2=(800-540)/2 if samplesize=="540-800";
 tab samplesize2, m;
 drop samplesize;
 rename samplesize2 samplesize;
 tostring sourcecategory ref1_name noneother ref1 cons1, replace;
};
if "`y'"=="04" tostring ref1_name sourcecategory source4 source5 source6 sponsor4
	 undecidedunsure none noneotherunsure ref1 cons1, replace;
if "`y'"=="00" {;
 tostring source3 source4 source5 source6 sponsor4 ind1 otherundecided 
	sourcecategory ref1 noneother noneotherunsure cons1 wouldntvote otherwouldntvote
	nonewouldntvote, replace;
 gen year=2000;
};
save "${prepoll`y'}polls`y'.dta", replace;
clear;
};

/*
use "${oldpoll00}2000pres.dta";
des;
*make data stackable with new 2004 & 2008 data from PR.com;
rename source source1;
rename sponsor sponsor1;
count if samplesize!=sizesample;
drop sizesample;
*convert to string for append, where necessary;
tostring ind1 lib1 green1 otherundecided, replace;
*/

use "${prepoll00}polls00.dta";
replace year=2000;
append using "${prepoll04}polls04.dta";
des;
append using "${prepoll08}polls08.dta";
sum;
bysort year: tab notes;

*check key variables and convert to numeric where necessary;
*STATE MOE N;
tab state,m; *ok;
tab marginoferror,m; *ok;
tab samplesize,m; *ok;

*VOTER TYPE;
tab votertype year,m;
gen votertype2=substr(votertype, 1,15);
gen vtype="l" if votertype=="l"|votertype=="lv"|votertype=="pv"|votertype=="lv/avd"
	|votertype=="lv/ev"
	|votertype2=="most-likely vot"|votertype2=="probable voters"
	|votertype2=="more likely vot"|votertype2=="most likely vot";
replace vtype="r" if votertype=="r"|votertype=="rv"|votertype2=="registered vote";
replace vtype="o" if vtype==""&votertype!=""&votertype!=".";
tab votertype2 vtype;
drop votertype*;
tab vtype, m;
label var vtype "type of voter";

/*
*CANDIDATE NAMES;
for any rep1 dem1 ind1 ref1 ref2 lib1 green1 nl1 tax1 rl1 ah1 ai1 dem2 rep2 cons:
 tab X_name year,m;
*no variation within year in candidate name;
*missings in 2004 & 2008 not entered b/c no variation in name observed;
for any rep1 dem1 ind1 ref1 ref2 lib1 green1 nl1 tax1 rl1 ah1 ai1 dem2 rep2 cons:
 drop X_name;
*/
drop *_name;

*CANDIDATE VOTE SHARES;
for any rep1 dem1 ind1 ref1 ref2 lib1 green1 nl1 cons1:
 tab X,m;
*ind1 ref1 lib1 green1 cons1 nl1 have non-numeric characters;
*treat "-" as 0% and "n/a" "?" and "." as missing;
for any ind1 ref1 lib1 green1 cons1 nl1:
 replace X="0" if X=="-" \
 replace X="" if X=="n/a"|X=="."|X=="?" \ 
 destring X, replace;
sum rep1 dem1 ind1 ref1 ref2 lib1 green1 nl1 cons1;
bysort year: sum rep1 dem1 ind1 ref1 ref2 lib1 green1 nl1 cons1;

*OTHER UNDECIDED ETC.;
for any other otherundecided undecided undecidedunsure neither none noneother noneunsure 
	neitherotherunsure noneotherunsure otherneither wouldntvote refused noanswer
	otherwouldntvote unsurewouldnt othernader nonewouldntvote undecidedrefused:
	tab X, m;
*other otherundecided undecided undecidedunsure none noneotherunsure wouldntvote
	otherwouldntvote  noneother nonewouldntvote have non-numeric chars;
*treat "-" as 0% & "." "n/a" as missing;
for any other otherundecided undecided undecidedunsure none noneotherunsure wouldntvote
    noneother nonewouldntvote otherwouldntvote:
 replace X="0" if X=="-" \
 replace X="" if X=="."|X=="n/a"|X=="KOB-TV" \
 destring X, replace;
sum other otherundecided undecided undecidedunsure neither none noneother noneunsure
        noneotherunsure otherneither wouldntvote nonewouldntvote refused noanswer
	neitherotherunsure otherwouldntvote unsurewouldnt othernader undecidedrefused;
bysort year: sum other otherundecided undecided undecidedunsure neither none noneother
	noneunsure noneotherunsure otherneither wouldntvote nonewouldntvote refused
	noanswer neitherotherunsure otherwouldntvote unsurewouldnt othernader
	undecidedrefused;
*combine some of these categories - OTHER UNDEC OTHERUNDEC NONE;
egen tmp_other=rsum(other neither noneother otherneither otherwouldntvote othernader);
egen tmp_undecided=rsum(undecided undecidedunsure noneunsure unsurewouldnt);
egen tmp_otherundecided=rsum(otherundecided noneotherunsure neitherotherunsure
	 undecidedrefused);
egen tmp_none=rsum(none wouldntvote refused noanswer nonewouldntvote);
egen totothers=rsum(other otherundecided undecided undecidedunsure neither none noneother
        noneunsure noneotherunsure otherneither wouldntvote nonewouldntvote refused
	noanswer neitherotherunsure otherwouldntvote unsurewouldnt othernader
	undecidedrefused);
egen tmp_totothers=rsum(tmp_*);
count if totothers!=tmp_totothers;
drop tmp_totothers;
drop other otherundecided undecided undecidedunsure neither none noneother
        noneunsure noneotherunsure otherneither wouldntvote nonewouldntvote refused
	noanswer neitherotherunsure otherwouldntvote unsurewouldnt othernader;
for any other undecided otherundecided none: rename tmp_X X;
sum other undecided otherundecided none;

tab sourceparty year, m;
replace sourceparty="d" if sourceparty=="D";
replace sourceparty="r" if sourceparty=="R";
replace sourceparty="" if sourceparty=="DR";

tab sponsorparty year, m;
replace sponsorparty="d" if sponsorparty=="D";
replace sponsorparty="r" if sponsorparty=="R";
replace sponsorparty="" if sponsorparty=="DR";
tab sourceparty year, m;
tab sponsorparty year, m;

order record year state source1 source2-source6 sourcep sourcec
 sponsor1 sponsor2-sponsor4 sponsorp startdate-green1 cons1 other-totothers vtype notes;

*TOTAL PREDICTED %;
egen totpred=rsum(rep1 dem1 ind1 ref1 lib1 green1 cons1 totothers ref2 nl1);
sum totpred, det;
des;


* =============== ;
* Label variables ;
* =============== ;

label variable record "Record number" ;
label variable year "Calendar year of election" ;
label variable state "US state where election held" ;

for num 1/6: label variable sourceX "Source X";
label variable sourceparty "Source party, R=Rep, D=Dem, N=none indicated" ;
for num 1/4: label variable sponsorX "Sponsor X";
label variable sponsorparty "Sponsor party, R=Rep, D=Dem, N=none" ;
label variable sourcecategory "Source category" ;
label variable startdate "Start date of poll, M/D/YY string";
label variable enddate "End date of poll, M/D/YY string";

label variable samplesize "Number polled" ;
*label variable votertype "Adult,CertV,Def,Likely,MostL,Prob,Reg,REgular,WouldV" ;
label var vtype "Likely, Registered, Other";
label variable marginoferror "Reported margin of error for poll" ;

*label variable rep1_name "Republican 1st candidate-name" ;
label variable rep1 "Republican 1st candidate-predicted percentage of vote" ;

*label variable dem1_name "Democrat 1st candidate-name" ;
label variable dem1 "Democrat 1st candidate-predicted percentage of vote" ;

*label variable ind1_name "Independent 1st candidate-name" ;
label variable ind1 "Independent 1st candidate-predicted percentage of vote" ;

*label variable ref1_name "Reform 1st candidate-name" ;
label variable ref1 "Reform 1st candidate-predicted percentage of vote" ;

*label variable lib1_name "Libertarian 1st candidate-name" ;
label variable lib1 "Libertarian 1st candidate-predicted percentage of vote" ;

*label variable green1_name "Green 1st candidate-name" ;
label variable green1 "Green 1st candidate-predicted percentage of vote" ;

label variable other "Preference for any of neither noneother otherneither";
label variable otherundecided "Preference for any of otherundecided noneotherunsure";
label variable undecided "Preference for any of undecided undecidedunsure noneunsure";
label var none "Preference for none wouldntvote refused noanswer";
label var totothers "Total of all other/undec/none/... preferences";
label variable notes "Notes" ;

label variable totpred "Total predicted percentage of votes" ;

des;

* ======================== ;
* Look for duplicates, etc.;
* ======================== ;

replace record=year*1000+record;
format record %15.0g;
sort state year source1 sponsor1 enddate startdate vtype samplesize margin;
***duplicates on all vars***;
duplicates tag year state source* sponsor* *date sample margin rep1 dem1 ind1 ref1 lib1 
		green1 cons1 ref2 nl1 other* undecided none* totothers vtype totpred,
		gen(dup);
tab year dup, m;
list if dup==1;  *these are 10 dupes in 2004 on all vars - repeated listings;
drop if record==2004363|record==2004496|record==2004625|record==2004624|record==2004765;
drop dup;

***duplicates on key vars***;
duplicates tag state year source1 sponsor1 enddate startdate vtype samplesize margin 
	rep1 dem1 ind1 ref1 lib1 green1 cons1 ref2 nl1 totothers, gen(dup);
tab year dup, m;
sort state year source1 sponsor1 enddate startdate vtype samplesize margin
	rep1 dem1 ind1 ref1 lib1 green1 cons1 ref2 nl1 totothers;
list if dup==1; *these are repeated listings with only slight differences - fix and drop;
drop if record==2004169|record==2004168|record==2004590;
drop dup;

***multiple sets of questions: third parites***;
duplicates tag state year source1 sponsor1 enddate startdate vtype samplesize margin,
	gen(dup);
tab year dup, m;
list if dup==1 in 1/150;  *most are cases where the pollster reports two sets of
				results, one with "others" and one b/w rep & dem;

*indicator for pollster reports two sets of results, one with "others" and one b/w
	 rep & dem;
gen duprep_3p=1 if dup==1&(ind1!=.|ref1!=.|lib1!=.|green1!=.|cons1!=.);
replace duprep_3p=0 if dup==1&(ind1==.&ref1==.&lib1==.&green1==.&cons1==.);
tab year duprep_3p, m;
egen tmp_gp=group(state year source1 sponsor1 enddate startdate vtype samplesize margin),
	missing;
egen tmp=sum(duprep_3p), by(tmp_gp); *tmp=1 if pairs of 0/1 duprep_3p;
tab tmp duprep_3p, m; *need to check the tmp=0 and tmp=2;

list if duprep_3p==0&tmp==0; *a couple of issues with these;
							*same 3rd party issue, but
							the extra category is other;
replace duprep_3p=1 if record==2004031|record==2004033|record==2004032;
							*incorrect date, the corrected
							poll already exists in data;
drop if record==2008354;
replace duprep_3p=. if record==2008353;
							*the next pair are legitimately
							two polls;
replace duprep_3p=. if record==2008683|record==2008682;

list if duprep_3p==1&tmp==2; *the 4 from 2004 are from one poll, two focus on a
				subsample of nader supporters and undecideds
				- drop these.
				the other two are a likely vs. registered split,
				addressed below.
				the 2 from 2000 are missed b/c both include ref, but
				one doesn't include green;
drop if record==2004708|record==2004707;
replace duprep_3p=. if record==2004705|record==2004706;
replace duprep_3p=0 if record==2000377;

drop dup;
drop tmp;
egen tmp=sum(duprep_3p), by(tmp_gp);
tab tmp duprep_3p, m; *again tmp=1 if pairs of 0/1 duprep_3p;
drop tmp;
egen count=count(tmp_gp), by(tmp_gp);
tab duprep_3p count;  *so 250 polls that ask two sets of q's:
				 one with 3+parties, one w/o;
drop tmp count;
tab year duprep_3p, m;


***multiple questions***;
duplicates tag state year source1 sponsor1 enddate startdate samplesize margin duprep_3p,
	gen(dup);
tab year dup, m;
list if dup>=1;
di notes[1952];
di notes[1953]; *these are legitimately two different polls;
gen duprep_not=1 if record==2008682|record==2008683;
drop dup;

***multiple sets of questions: likely voters***;
duplicates tag state year source1 sponsor1 enddate startdate duprep_3p duprep_not,
        gen(dup);
tab year dup, m;
list if dup==1 in 1/100;

*indicator for pollster reports two sets of results, one for LV and one for RV, etc;
egen tmp_gp=group(state year source1 sponsor1 enddate startdate duprep_3p duprep_not),
	missing;
egen tmp_nv=nvals(vtype) if dup==1, by(tmp_gp);
tab tmp_nv, m; *170 likely voter subsamples & 66 other issues - dealt with below;
gen duprep_lv=1 if dup==1&vtype=="l"&tmp_nv==2;
replace duprep_lv=0 if dup==1&vtype!="l"&tmp_nv==2;
tab year duprep_lv, m;

egen tmp=sum(duprep_lv), by(tmp_gp); *tmp=1 if pairs of 0/1 duprep_lv;
tab tmp duprep_lv, m; *ok!;
drop tmp;

*deal with other issues;
list if tmp_nv==1;  *many of these appear to be polls listed multiple times, but the
		     sample size given is only for the most recent poll under the heading
		     so need to drop the wrong ones;
		    *others contain different results despite sharing the same date.
		     exploring the raw data doesn't shed more light on this - treat
		     these as different polls;
duplicates tag state year source1 sponsor1 enddate startdate
		 duprep_3p duprep_not rep1 dem1, gen(dup2);
tab dup2 if tmp_nv==1, m;
gen duprep_weird=1 if tmp_nv==1&dup2==0;
list if tmp_nv==1&dup2==1;

drop if record==2008031;		*keep originial listing;
replace tmp_nv=. if record==2008035;
drop if record==2008042;		*keep originial listing;
replace tmp_nv=. if record==2008046;
drop if record==2008685;		*keep originial listing;
replace tmp_nv=. if record==2008684;
replace duprep_lv=1 if record==2004977; *split on a non-likely voter sample;
replace duprep_lv=0 if record==2004976;

drop tmp* dup dup2;

for var duprep*: tab year X, m;
drop duprep_not;

/*
summary:

polls that ask the respondent to respond to a question 2 ways, one with third parties/other, one with just rep & dem.

->  tab year duprep_3p, m

  Calendar |
   year of |            duprep_3p
  election |         0          1          . |     Total
-----------+---------------------------------+----------
      2000 |        14         14        474 |       502 
      2004 |       187        187        613 |       987 
      2008 |        49         49        631 |       729 
-----------+---------------------------------+----------
     Total |       250        250      1,718 |     2,218 


polls that report a likely voter (or in one case "likelier voter") subsample as well as a main, usually "registered voter", sample

->  tab year duprep_lv, m

  Calendar |
   year of |            duprep_lv
  election |         0          1          . |     Total
-----------+---------------------------------+----------
      2000 |         3          3        496 |       502 
      2004 |        81         81        825 |       987 
      2008 |         2          2        725 |       729 
-----------+---------------------------------+----------
     Total |        86         86      2,046 |     2,218 


polls that appear to be duplicate listings (by date and source, etc.), but inexplicably have different sample sizes and results.

->  tab year duprep_weird, m

  Calendar |
   year of |     duprep_weird
  election |         1          . |     Total
-----------+----------------------+----------
      2000 |         0        502 |       502 
      2004 |        44        943 |       987 
      2008 |        14        715 |       729 
-----------+----------------------+----------
     Total |        58      2,160 |     2,218 

*/



* ======================== ;
* Drop fucked observations ;
* ======================== ;

tab totpred;
bysort year: sum totpred, det;
gen predless = 100 - totpred ; *CHECK - 98-totpred? ;
*allow totals up to 102%, allowing for some rounding error;
replace predless = 0 if totpred > 100 & totpred <= 102 ; *CHECK ;
label variable predless "100 - totpred" ;

* drop crazy high totals (anything over 102) ;
tab predless;
tab year if predless<0;
drop if predless < 0 ; 
*4 total observations in the old 2000/2004, none in the PR.com 2008 data;
*UPDATE: using new 2004 data only 3 total dropped here from old 2000 data;
*UPDATE: none dropped using new data and above cleaning;

* ================================================== ;
* Dates ;
* New variables: elec_d, polldur, daysbef ;
* ================================================== ;

foreach var in enddate startdate {;
rename `var' tmp;
replace tmp=regexr(tmp, "/", " ");
replace tmp=regexr(tmp, "/", " ");
gen wc=wordcount(tmp);
tab wc, m;
gen m=word(tmp, 1);
destring m, replace;
gen d=word(tmp, 2);
if "`var'"=="enddate" replace d="15" if d=="??";
if "`var'"=="startdate" replace d="" if d=="??";
destring d, replace;
gen y=word(tmp, 3);
destring y, replace;
replace y=2000+y if y<100;
tab m,m;
tab d,m;
tab y,m;
tab year y;
*drop if y==2006;
list record year tmp *date if y==2007;
replace y=2004 if y==2007&year==2004;
gen `var'=mdy(m,d,y);
drop m d y tmp wc;
format `var' %td ;
};
label variable startd "Poll start date, Stata serial number" ;
label variable endd "Poll end date, Stata serial number" ;

* --------------------- ;
* Actual election dates ;
* --------------------- ;

gen elec_d = . ;
replace elec_d = 14186 if year == 1998 ;
replace elec_d = 14563 if year == 1999 ;
replace elec_d = 14921 if year == 2000 ;
replace elec_d = 15110 if year == 2001 ;
replace elec_d = 16377 if year == 2004 ;
replace elec_d = mdy(11,4,2008) if year == 2008 ;
label variable elec_d "Election date" ;

format elec_d %td ;
tab elec_d;

* ------------- ;
* Poll duration ;
* ------------- ;

gen byte polldur = endd - startd ;
label variable polldur "Duration of poll in days" ;

sum polldur, d ;
bysort year: sum polldur, d ;

* ---------------------------------------- ;
* Time before election that poll was taken ;
* ---------------------------------------- ;

gen daysbef = elec_d - endd ;
label variable daysbef "Time between poll end and election in days" ;
sum daysbef, d ;
list record state year daysbef enddate startdate if daysbef>150;
*accidentally entered a few early polls - drop these;
drop if daysbef>200&daysbef!=.;

* ------------------------ ;
* race identifier variable ;
* ------------------------ ;

egen rstate = group(state) ;
label variable rstate "Race state, numerical" ;

egen raceid = group(year rstate);
label variable raceid "Race identifier, based on year, state";

egen racen = count(raceid), by(raceid) ;
label variable racen "Number of polls per race, NOT mainsamp" ;
egen tagr=tag(raceid) ;
tab racen if tagr==1 ;
drop tagr ;

/*
* ------------------------------------------- ;
* Sum of predicted probabilities, _tot, _tot2 ;
*	Note: _tot2 = totpred ;
* ------------------------------------------- ;

egen _tot = rsum(dem1 rep1 ind1 ref1 lib1 green1 ref2 nl1);
label variable _tot "Total predicted percentages, without other/undecide" ;

sum _tot, d ;
sum _tot other otherun undecided none if _tot < 75 ;
list record year _tot other otherun undecided none totpred if _tot < 75 ;

egen _tot2 = rsum(_tot other otherun undecided none) ;
label variable _tot2 "Total predicted percentages, with other/undecided" ;

sum _tot2, d ;
sum _tot2 _tot other otherun undecided none if _tot2 < 90 ;
egen _smprty = rsum(ind1 ref1 lib1 green1 ref2 nl1);
label variable _smprty "Total predicted percentages for non-R1/D1 parties" ;

list record year _tot2 _tot _smprty other otherun undecided none if _tot2 < 90 ;
list record year _tot2 _tot _smprty other otherun undecided none if _tot2 > 101 ;

drop _smprty _tot _tot2;
*/

* --------------------------------------------- ;
* Generate putative margin of error, n of polls ;
* --------------------------------------------- ;

*fraction for dem of dem+rep vote share;
gen dem1_dr=100*dem1/(dem1+rep1);
sum dem1_dr, det;

gen putmarg_d = 100*invnorm(.975)*sqrt((dem1/100)*(1-(dem1/100))/samplesize) ;
gen putmarg_r = 100*invnorm(.975)*sqrt((rep1/100)*(1-(rep1/100))/samplesize) ;
gen putmarg_50 = 100*invnorm(.975)*sqrt((50/100)*(1-(50/100))/samplesize) ;
gen putmarg_scale = 100*invnorm(.975)*sqrt((dem1_dr/100)*(1-(dem1_dr/100))/samplesize) ;
pwcorr putmarg* marg;
sum putmarg* marg;

for any d r 50 scale:
 gen putlessactmarg_X = putmarg_X - marginoferror ;

label variable putmarg_d "Putative margin of error, 5% level using Dem share" ;
label variable putmarg_r "Putative margin of error, 5% level using Rep share" ;
label variable putmarg_50 "Putative margin of error, 5% level using 50-50" ;
label variable putmarg_scale "Putative margin of error, 5% level using rescaled share" ;
sum putlessactm*, det;

gen putn_d = (dem1/100)*(1-(dem1/100))*(invnorm(.975)^2)/((marginoferror/100)^2) ;
gen putn_r = (rep1/100)*(1-(rep1/100))*(invnorm(.975)^2)/((marginoferror/100)^2) ;
gen putn_50 = (50/100)*(1-(50/100))*(invnorm(.975)^2)/((marginoferror/100)^2) ;
gen putn_scale = (dem1_dr/100)*(1-(dem1_dr/100))*(invnorm(.975)^2)/((marginoferror/100)^2) ;
pwcorr putn* marg;
sum putn* marg;

for any d r 50 scale:
 gen putlessactn_X = putn_X - samplesize ;

label variable putn_d "Putative number of observations, 5% level using Dem share" ;
label variable putn_r "Putative number of observations, 5% level using Rep share" ;
label variable putn_50 "Putative number of observations, 5% level using 50-50" ;
label variable putn_scale "Putative number of observations, 5% level using rescaled share" ;
sum putlessactn*, det;

list record year samplesize putn_50 marginoferror putmarg_50 if
   (putlessactn_50>200|putlessactn_50<-200)&putlessactn_50!=.;
*hand checked the most egregious in 2008 - found no data entry errors;

* ======================================================== ;
* A. Treat reported undecideds, totpred < 100 as undecided ;
* ======================================================== ;
* Check records 1089, 1090: have other_un as well as other or undecided. OK. ;

egen allundec = rsum(undecided otherundecided predless) ;
label variable allundec "Fraction undecided (not including other/none)"; 
egen alloth = rsum(other none ind1 ref1 lib1 green1 cons1);
label variable alloth "Fraction other candidate/none/other";

gen byte indundec = allundec > 0 if allundec ~= . ;
label variable indundec "Dummy for any undecideds (not including other/none)";
sum undecided otherund predless allundec indundec;

gen temp = rep1 + dem1 + alloth + allundec ;
label variable temp "Total fraction predicted, should be 100, 101 or 102" ;
tab temp, m ;
sum temp, d ; *CHECK - a few are == 102 ... rounding error we allowed above;
drop temp;


replace state="Tennessee" if state=="Tennesse";



for var duprep*: tab year X, m;

des;
sum;
compress;
save ${prepoll}presprepolls.dta, replace;

log close ;
