capture log close
capture clear all
# delimit ;
set memory 50m ;
set more off ;
pause on ;
program drop _all ;

* =============================================================== ;
*	This is maketessallvars.do ; 
*	Last edited 12.30.08 ew ;
*	Uses tess28_dinardo_final_data.dta ;
*	creates weights, predicts results, deals with missings;
* =============================================================== ;

global N=1;
*1==umich server structure;
*2==elias's macbook structure;

if $N==1 {;
global tess "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/tess/";
global tessdata
   "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/tess/tess28_dinardo_final_data/";
global tab "/afs/umich.edu/user/f/g/fgelias/Shared/fin_pollproj/tables/";
};

if $N==2 {;
global tess "/Users/fgelias/Documents/umich/projects/pollproject/final_polls/tess/" ;
global results
	 "/Users/fgelias/Documents/umich/projects/pollproject/final_polls/results/" ;
};


log using ${tess}maketessallvars.log, replace ;

***read in and clean tess data***;

use "${tessdata}tess28_dinardo_final_data.dta" ;
compress ;

gen byte manski=(exp==2) if exp!=.;
tab wave manski, m;
tab svy_date wave ;

gen byte wave1=(wave==1) ;
gen byte wave2=(wave==2) ;

*if manski, we have the probability of voting if not, we ignore unlikely voter question ;

* not sure what to do with the missing probvoting people... ;
* only 4 of them... so forget them ;
gen miss_lv=(mq2a==. & mq2b==. & manski==1) | (cq2a==. & cq2b==. & manski==0) ;
label var miss_lv "missing probability of voting" ;
tab miss_lv manski ;
tab miss_lv wave ;
list if miss_lv==1; *3 of these have no poll results;
drop if miss_lv ;

gen byte kerry=mq3a_1 if manski==1;
gen byte bush=mq3a_2 if manski==1;
gen byte other=mq3a_3 if manski==1;
gen bushc=cq3==2 if cq3!=.  & manski==0;
summ bushc if manski==0;
gen kerryc=cq3==1 if  cq3!=. & manski==0;
summ kerryc if manski==0;
gen otherc=cq3==3 if  cq3!=. & manski==0;
summ otherc if manski==0;

replace bush=0 if kerry==100 | other==100 ;
replace kerry=0 if bush==100 | other==100 ;
replace other=0 if kerry==100 | bush==100 ;

egen tmp=rsum(bush kerry other) if manski==1;
tab tmp;
list bush kerry other tmp if (tmp!=100&tmp!=0)&manski==1;
for var bush kerry other: replace X=0 if X==.&tmp==100&manski==1;
drop tmp;
for var kerry bush other: replace X=X/100 if manski==1;

egen check1=rsum(kerry   bush   other) if manski==1 ;
egen temp1=rsum(kerryc bushc otherc) if manski==0 ;
replace check1=temp1 if manski==0 ;
drop temp1 ;
replace check1=round(check1,.01);
label variable check1 "success in summing ==1" ;
tab check1 if manski==1;
tab check1 if manski==0;

**probability of voting weights;
*manski;
tab mq2a mq2b;
gen tmp=mq2a==.&mq2b==. if manski==1;
tab tmp; drop tmp;
egen vwgtm1=rsum(mq2a mq2b) if manski==1 ;
summ vwgtm1, det;
local tot=r(sum);
gen pv=vwgtm1/100;
replace vwgtm1=vwgtm1/`tot' if manski==1 ;
summ vwgtm1 if manski==1 ;
display "Does it sum to 1? " r(sum) ;
label var pv "Probability of Voting" ;
label var vwgtm1 "Probability of Voting weight -- Manski" ;
*control;
tab cq2a cq2b;
gen tmp=cq2a==.&cq2b==. if manski==0;
tab tmp; drop tmp;
egen vwgtc1=rsum(cq2a cq2b) if manski==0;
replace vwgtc1=0 if vwgtc1==2;
tab vwgtc1 if manski==0;
replace pv=vwgtc1 if manski==0;
sum vwgtc1 if manski==0;
local tot=r(sum) ;
replace vwgtc1=vwgtc1/`tot' if manski==0 ;
label var pv "Probability of Voting" ;
label var vwgtc1 "Probability of Voting -- Control" ;
bysort manski: sum pv vwgtc1 vwgtm1;

for any work marit eth msacat hhhead: gen ppX_new=ppX==1;
replace ppwork_new=1 if ppwork==2|ppwork==3;
replace ppgender=ppgender==1;
gen ppage2=ppage^2;

*** create wave weights ***;
forval m=0/1 {;
 xi: probit wave1 ppage ppage2 i.ppeducat ppeth_new ppgender pphhhead_new ppmarit_new
	 ppmsacat_new i.ppreg4 ppwork_new if manski==`m';
 predict phat_pm`m' if manski==`m', p ;
 sum phat_pm`m', det ;
 xi: reg wave1 ppage ppage2 i.ppeducat ppeth_new ppgender pphhhead_new ppmarit_new
	 ppmsacat_new i.ppreg4 ppwork_new if manski==`m';
 predict phat_rm`m' if manski==`m';
 sum phat_rm`m', det ;

 pwcorr phat_pm`m' phat_rm`m';
 gen wgtwavem`m'=wave1*(1/phat_pm`m')+(1-wave1)*(1/(1-phat_pm`m')) if manski==`m' ;
 sum wgtwavem`m' if manski==`m', det ;
 local tot=r(sum) ;
 replace wgtwavem`m'= wgtwavem`m'/`tot' if manski==`m' ;
};


*** deal with missing ***;
gen miss_cand=check1==0;
label var miss_cand "missing candidate" ;
sum miss_cand ;
tab miss_cand manski, m;

forval m=0/1 {;
 xi: probit miss_cand ppage ppage2 i.ppeducat ppeth_new ppgender pphhhead_new ppmarit_new
	 ppmsacat_new i.ppreg4 ppwork_new if manski==`m';
 predict phat_miss_cand_pm`m' if manski==`m', p ;
 sum phat_miss_cand_pm`m', det ;
 xi: reg miss_cand ppage ppage2 i.ppeducat ppeth_new ppgender pphhhead_new ppmarit_new
	 ppmsacat_new i.ppreg4 ppwork_new if manski==`m';
 predict phat_miss_cand_rm`m' if manski==`m';
 sum phat_miss_cand_rm`m', det ;

 pwcorr phat_miss_cand_pm`m' phat_miss_cand_rm`m';
 gen wgtmissm`m'=1/(1-phat_miss_cand_pm`m') if manski==`m';
 sum wgtmissm`m' if manski==`m', det ;
 local tot=r(sum) ;
 replace wgtmissm`m'= wgtmissm`m'/`tot' if manski==`m' ;
};
drop if miss_cand==1;
drop miss_cand check1;

*** create weights for analysis ***;

sum weight if manski==1;
gen weight_m1=weight/r(sum) if manski==1;
sum weight if manski==0;
gen weight_m0=weight/r(sum) if manski==0;

gen weightm=vwgtm1*weight_m1 if manski==1;
gen weightc=vwgtc1*weight_m0 if manski==0;
label variable weightm "combined probvoting & kn weight" ;
label variable weightc "combined probvoting & kn weight" ;

gen missweightm=weightm*wgtmissm1 if manski==1 ;
gen missweightc=weightc*wgtmissm0 if manski==0 ;
label variable missweightm "combined probvoting, kn & missing weight" ;
label variable missweightc "combined probvoting, kn & missing weight" ;

gen wwgtm=weight_m1*wgtwavem1 if manski==1 ;
gen wwgtc=weight_m0*wgtwavem0 if manski==0;
label variable wwgtm "combined kn & wave weight" ;
label variable wwgtc "combined kn & wave weight" ;

gen wweightm=weightm*wgtwavem1 if manski==1;
gen wweightc=weightc*wgtwavem0 if manski==0;
label variable wweightm "combined probvoting, kn & wave weight" ;
label variable wweightc "combined probvoting, kn & wave weight" ;

gen wmissweightm=missweightm*wgtwavem1 if manski==1;
gen wmissweightc=missweightc*wgtwavem0 if manski==0;
label variable wmissweightm "combined probvoting, kn, missing & wave weight" ;
label variable wmissweightc "combined probvoting, kn, missing & wave weight" ;

bysort manski: sum weightm missweightm wwgtm wweightm wmissweightm 
		   weightc missweightc wwgtc wweightc wmissweightc;
sum bush kerry other, det ;
tab bush ;
tab kerry ;
tab other ;

compress;
des;
save ${tess}tessallvars.dta, replace;

log close ;
